==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/classes/Http/TwigTemplaterResponse.php <==
<?php
namespace Claromentis\Core\Http;

$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] ?: array()) + array("_4d707fab93bebb00bbe" . "69e8159697c90" => base64_decode(""));








class TwigTemplaterResponse extends TwigResponse
{
    
    
    
    
    
    
    protected $page_title;
    
    
    
    
    
    
    protected $message;
    
    
    
    
    
    
    protected $is_error_message;
    
    
    
    
    
    
    
    
    public function __construct(string $template, array $arguments = [], string $_678d945258a520c3df1c42fe4b558f34 = '')
    {
        parent::__construct($template, $arguments);
        $this->setPageTitle($_678d945258a520c3df1c42fe4b558f34);
        $this->setMessage($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_4d707fab93bebb00bbe" . "69e8159697c90"], false);
    }
    
    
    
    
    
    
    public function getPageTitle() : string
    {
        return $this->page_title;
    }
    
    
    
    
    
    
    public function setPageTitle(string $_678d945258a520c3df1c42fe4b558f34) : void
    {
        $this->page_title = $_678d945258a520c3df1c42fe4b558f34;
    }
    
    
    
    
    
    
    public function getMessage() : string
    {
        return $this->message;
    }
    
    
    
    
    
    
    
    public function setMessage(string $_e05e0022a2e5ad344b9c4a0d3f64e1a5, bool $_8df4fa2d5c8d8c2e6de4577a36506bb1 = false) : void
    {
        $this->message = $_e05e0022a2e5ad344b9c4a0d3f64e1a5;
        $this->is_error_message = $_8df4fa2d5c8d8c2e6de4577a36506bb1;
    }
    
    
    
    
    
    
    public function isErrorMessage() : bool
    {
        return $this->is_error_message;
    }
    
    
    
    
    
    
    public function setIsErrorMessage(bool $_8df4fa2d5c8d8c2e6de4577a36506bb1) : void
    {
        $this->is_error_message = $_8df4fa2d5c8d8c2e6de4577a36506bb1;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/classes/Http/TwigTemplaterResponse.php <==
<?php
namespace Claromentis\Core\Http;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] ?: array()) + array("_4d707fab93bebb00bbe69e8159697c9" . "0" => base64_decode(""));








class TwigTemplaterResponse extends TwigResponse
{
    
    
    
    
    
    
    protected $page_title;
    
    
    
    
    
    
    protected $message;
    
    
    
    
    
    
    protected $is_error_message;
    
    
    
    
    
    
    
    
    public function __construct(string $template, array $arguments = [], string $_678d945258a520c3df1c42fe4b558f34 = '')
    {
        parent::__construct($template, $arguments);
        $this->setPageTitle($_678d945258a520c3df1c42fe4b558f34);
        $this->setMessage($GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_4d707fab93b" . "ebb00bbe69e8" . "159697c90"], false);
    }
    
    
    
    
    
    
    public function getPageTitle() : string
    {
        return $this->page_title;
    }
    
    
    
    
    
    
    public function setPageTitle(string $_678d945258a520c3df1c42fe4b558f34) : void
    {
        $this->page_title = $_678d945258a520c3df1c42fe4b558f34;
    }
    
    
    
    
    
    
    public function getMessage() : string
    {
        return $this->message;
    }
    
    
    
    
    
    
    
    public function setMessage(string $_e05e0022a2e5ad344b9c4a0d3f64e1a5, bool $_8df4fa2d5c8d8c2e6de4577a36506bb1 = false) : void
    {
        $this->message = $_e05e0022a2e5ad344b9c4a0d3f64e1a5;
        $this->is_error_message = $_8df4fa2d5c8d8c2e6de4577a36506bb1;
    }
    
    
    
    
    
    
    public function isErrorMessage() : bool
    {
        return $this->is_error_message;
    }
    
    
    
    
    
    
    public function setIsErrorMessage(bool $_8df4fa2d5c8d8c2e6de4577a36506bb1) : void
    {
        $this->is_error_message = $_8df4fa2d5c8d8c2e6de4577a36506bb1;
    }
}
